@@ -1,15 +1,15 @@
 package Net::DNS::RR::PX;
 #
-# $Id: PX.pm 632 2007-03-12 13:24:21Z olaf $
+# $Id: PX.pm 932 2011-10-26 12:40:48Z willem $
 #
 use strict;
-BEGIN { 
+BEGIN {
     eval { require bytes; }
-} 
+}
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 632 $)[1];
+$VERSION = (qw$LastChangedRevision: 932 $)[1];
 
 
 
@@ -50,10 +50,8 @@ sub new_from_string {
 
 	if ($string && ($string =~ /^(\d+)\s+(\S+)\s+(\S+)$/)) {
 		$self->{"preference"} = $1;
-		$self->{"map822"}     = $2;
-		$self->{"mapx400"}    = $3;
-		$self->{"map822"}     =~ s/\.+$//;;
-		$self->{"mapx400"}    =~ s/\.+$//;;
+		$self->{"map822"}     =Net::DNS::stripdot($2);
+		$self->{"mapx400"}    =Net::DNS::stripdot($3);
 	}
 
 	return bless $self, $class;
@@ -85,6 +83,16 @@ sub rr_rdata {
 }
 
 
+
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{'map822'}=Net::DNS::stripdot($self->{'map822'}) if defined $self->{'map822'};
+	$self->{'mapx400'}=Net::DNS::stripdot($self->{'mapx400'}) if defined $self->{'mapx400'};
+}
+
+
+
 sub _canonicalRdata {
 	my ($self) = shift;
 	my $rdata = "";
@@ -136,7 +144,7 @@ Returns the X.400 part of the RFC1327 mapping information.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 Portions Copyright (c) 2005 Olaf Kolkman NLnet Labs.
